"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const StopTestRunnerWhenTestsComplete_1 = require("./StopTestRunnerWhenTestsComplete");
const Emitter_1 = require("../Emitter");
class StubCallFlowSession extends Emitter_1.TypedEmitter {
}
describe("Close server when tests complete", () => {
    let pluginEmitter;
    let testRunner;
    beforeEach(() => {
        pluginEmitter = new Emitter_1.TypedEmitter();
        testRunner = {
            stop: jest.fn(),
        };
    });
    test("test runner stopped when all test sessions have matched all their prompts", () => {
        const stopWhenAllTestsComplete = new StopTestRunnerWhenTestsComplete_1.StopTestRunnerWhenTestsComplete();
        stopWhenAllTestsComplete.initialise(pluginEmitter, testRunner);
        const callFlowSession = new StubCallFlowSession();
        const testSession = {
            callFlowTestDefinition: undefined,
            call: undefined,
            callFlowSession,
        };
        stopWhenAllTestsComplete.testStarted(testSession);
        callFlowSession.emit("allPromptsMatched", {
            transcription: "",
        });
        expect(testRunner.stop).toHaveBeenCalledWith(false);
    });
    test("test runner stopped with failure if any test sessions have timed-out", () => {
        const stopWhenAllTestsComplete = new StopTestRunnerWhenTestsComplete_1.StopTestRunnerWhenTestsComplete();
        stopWhenAllTestsComplete.initialise(pluginEmitter, testRunner);
        const testSession1 = {
            callFlowTestDefinition: undefined,
            call: undefined,
            callFlowSession: new StubCallFlowSession(),
        };
        const testSession2 = {
            callFlowTestDefinition: undefined,
            call: undefined,
            callFlowSession: new StubCallFlowSession(),
        };
        stopWhenAllTestsComplete.testStarted(testSession1);
        stopWhenAllTestsComplete.testStarted(testSession2);
        testSession1.callFlowSession.emit("allPromptsMatched", {});
        testSession2.callFlowSession.emit("timeoutWaitingForMatch", {
            transcription: "",
        });
        const failure = true;
        expect(testRunner.stop).toHaveBeenCalledWith(failure);
    });
    test("test runner not stopped until all test sessions have matched all their prompts", () => {
        const stopWhenAllTestsComplete = new StopTestRunnerWhenTestsComplete_1.StopTestRunnerWhenTestsComplete();
        stopWhenAllTestsComplete.initialise(pluginEmitter, testRunner);
        const testSession1 = {
            callFlowTestDefinition: undefined,
            call: undefined,
            callFlowSession: new StubCallFlowSession(),
        };
        const testSession2 = {
            callFlowTestDefinition: undefined,
            call: undefined,
            callFlowSession: new StubCallFlowSession(),
        };
        stopWhenAllTestsComplete.testStarted(testSession1);
        stopWhenAllTestsComplete.testStarted(testSession2);
        testSession1.callFlowSession.emit("allPromptsMatched", {});
        expect(testRunner.stop).not.toHaveBeenCalled();
    });
});
